@@ -503,6 +503,11 @@ class DatabaseWrapper(BaseDatabaseWrapper):
                         table_name, column_name, bad_row[1],
                         referenced_table_name, referenced_column_name))
 
+    def schema_editor(self, *args, **kwargs):
+        "Returns a new instance of this backend's SchemaEditor"
+        from django.db.backends.mysql.schema import DatabaseSchemaEditor
+        return DatabaseSchemaEditor(self, *args, **kwargs)
+
     def is_usable(self):
         try:
             self.connection.ping()
